horseshoe2D: Horseshoe domain

horseshoe2DR Documentation

Horseshoe domain

Description

The boundary and interior nodes and connectivity matrix of a triangular mesh of the horseshoe domain. This dataset can be used to create a mesh.2D object with the function create.mesh.2D.


fdaPDE documentation built on June 5, 2026, 1:06 a.m.