hub2.5D: Hub domain

hub2.5DR Documentation

Hub domain

Description

The nodes and connectivity matrix of a triangular mesh of a manifold representing a hub geometry. This dataset can be used to create a MESH.2.5D object with the function create.MESH.2.5D.


fdaPDE documentation built on June 5, 2026, 1:06 a.m.