R_smooth.FEM.basis(locations, observations, FEMbasis, lambda, covariates, GCV)observations.locations argument.
Otherwise if only the vector of observations is given, these are consider to be located in the corresponding node in the table nodes of the mesh. In this last
case, an NA value in the observations vector indicates that there is no observation associated to the corresponding node.EMbasis object describing the Finite Element basis, as created by create.FEM.basis.observations.TRUE the following quantities are computed: the trace of the smoothing matrix, the estimated error standard deviation, and
the Generalized Cross Validation criterion, for each value of the smoothing parameter specified in lambda.fit.FEMFEM object that represents the fitted spatial field.PDEmisfit.FEMFEM object that represents the Laplacian of the estimated spatial field.betaNULL, a vector of length #covariates with the regression coefficients associated with each covariate.edfTRUE, a scalar or vector with the trace of the smoothing matrix for each value of the smoothing parameter specified in lambda.stderrTRUE, a scalar or vector with the estimate of the standard deviation of the error for each value of the smoothing parameter specified in lambda.GCVTRUE, a scalar or vector with the value of the GCV criterion for each value of the smoothing parameter specified in lambda.smooth.FEM.basis, smooth.FEM.PDE.basis, smooth.FEM.PDE.sv.basis